netapp_ontap.resources.iscsi_credentials API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.resources.iscsi_credentials`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Overview

An iSCSI credentials object defines authentication credentials to be used between an initiator and ONTAP. It identifies an authentication type, user names, and passwords that must be used to authenticate a specific initiator.
The iSCSI credentials REST API allows you to create, update, delete, and discover iSCSI credentials.

## How iSCSI authentication works

An iSCSI credentials object defines the authentication credentials to be used between an initiator and ONTAP. While establishing an iSCSI connection, the initiator sends a login request to ONTAP to begin an iSCSI session. ONTAP then either permits or denies the login request, or determines that a login is not required.

For an initiator, you can specify an authentication type, user names and passwords, and a whitelist of optional network addresses from which the initiator is allowed to connect.

## iSCSI authentication methods

- Challenge-Handshake Authentication Protocol (CHAP) - The initiator logs in using a CHAP user name and password. There are two types of CHAP user names and passwords:
  - Inbound - ONTAP authenticates the initiator. Inbound settings are required if you are using CHAP authentication.
  - Outbound - These are optional credentials to enable the initiator to authenticate ONTAP. You can use credentials only if inbound credentials are also being used.
- deny - The initiator is denied access to ONTAP.
- none - ONTAP does not require authentication for the initiator. The CHAP inbound/outbound password can be any valid string or an even number of valid hexadecimal digits preceded by '0X' or '0x'.

## Initiator address list

The initiator address list is a way to specify valid IP addresses from which the initiator is allowed to connect. If the list is specified and the source address of an iSCSI connection is not in the list, the connection is rejected. Initiator addresses can be specified in either IPv4 or IPv6 format and in one of two forms: - Range `{ "start": "192.168.0.0", "end": "192.168.0.255" }` - Mask `{ "address": "192.168.0.0", "netmask": "24" }`

## Initiator "default"

The default iSCSI authentication definition is created when the iSCSI service is created. An iSCSI credentials object with default as the initiator name identifies the default authentication for an SVM. The default credentials are used for any initiator that does not have specific iSCSI credentials. The default iSCSI authentication method is none, but can be changed to deny or CHAP. The default credentials object does not support an initiator address list.

## Examples

### Creating iSCSI credentials requiring no authentication

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import IscsiCredentials

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = IscsiCredentials()
        resource.svm = {"name": "svm1"}
        resource.initiator = "iqn.1992-08.com.netapp:initiator1"
        resource.authentication_type = "none"
        resource.post(hydrate=True)
        print(resource)

### Creating iSCSI credentials using CHAP inbound authentication

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import IscsiCredentials

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = IscsiCredentials()
        resource.svm = {"name": "svm1"}
        resource.initiator = "iqn.1992-08.com.netapp:initiator2"
        resource.authentication_type = "CHAP"
        resource.chap = {"inbound": {"user": "user1", "password": "password1"}}
        resource.post(hydrate=True)
        print(resource)

### Retrieving all properties of all iSCSI credentials

The `fields` query parameter is used to request all iSCSI credentials properties.
Passwords are not included in the GET output.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import IscsiCredentials

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        print(list(IscsiCredentials.get_collection(fields="*")))

Try it out

    [
        IscsiCredentials(
            {
                "initiator": "default",
                "_links": {
                    "self": {
                        "href": "/api/protocols/san/iscsi/credentials/19d04b8e-94d7-11e8-8370-005056b48fd2/default"
                    }
                },
                "authentication_type": "none",
                "svm": {
                    "name": "svm1",
                    "_links": {
                        "self": {
                            "href": "/api/svm/svms/19d04b8e-94d7-11e8-8370-005056b48fd2"
                        }
                    },
                    "uuid": "19d04b8e-94d7-11e8-8370-005056b48fd2",
                },
            }
        ),
        IscsiCredentials(
            {
                "initiator": "iqn.1992-08.com.netapp:initiator1",
                "_links": {
                    "self": {
                        "href": "/api/protocols/san/iscsi/credentials/19d04b8e-94d7-11e8-8370-005056b48fd2/iqn.1992-08.com.netapp:initiator1"
                    }
                },
                "authentication_type": "none",
                "svm": {
                    "name": "svm1",
                    "_links": {
                        "self": {
                            "href": "/api/svm/svms/19d04b8e-94d7-11e8-8370-005056b48fd2"
                        }
                    },
                    "uuid": "19d04b8e-94d7-11e8-8370-005056b48fd2",
                },
            }
        ),
        IscsiCredentials(
            {
                "initiator": "iqn.1992-08.com.netapp:initiator2",
                "_links": {
                    "self": {
                        "href": "/api/protocols/san/iscsi/credentials/19d04b8e-94d7-11e8-8370-005056b48fd2/iqn.1992-08.com.netapp:initiator2"
                    }
                },
                "chap": {"inbound": {"user": "user1"}},
                "authentication_type": "chap",
                "svm": {
                    "name": "svm1",
                    "_links": {
                        "self": {
                            "href": "/api/svm/svms/19d04b8e-94d7-11e8-8370-005056b48fd2"
                        }
                    },
                    "uuid": "19d04b8e-94d7-11e8-8370-005056b48fd2",
                },
            }
        ),
        IscsiCredentials(
            {
                "initiator": "default",
                "_links": {
                    "self": {
                        "href": "/api/protocols/san/iscsi/credentials/25f617cf-94d7-11e8-8370-005056b48fd2/default"
                    }
                },
                "authentication_type": "none",
                "svm": {
                    "name": "svm2",
                    "_links": {
                        "self": {
                            "href": "/api/svm/svms/25f617cf-94d7-11e8-8370-005056b48fd2"
                        }
                    },
                    "uuid": "25f617cf-94d7-11e8-8370-005056b48fd2",
                },
            }
        ),
        IscsiCredentials(
            {
                "initiator": "iqn.1992-08.com.netapp:initiator2",
                "_links": {
                    "self": {
                        "href": "/api/protocols/san/iscsi/credentials/25f617cf-94d7-11e8-8370-005056b48fd2/iqn.1992-08.com.netapp:initiator2"
                    }
                },
                "authentication_type": "none",
                "svm": {
                    "name": "svm2",
                    "_links": {
                        "self": {
                            "href": "/api/svm/svms/25f617cf-94d7-11e8-8370-005056b48fd2"
                        }
                    },
                    "uuid": "25f617cf-94d7-11e8-8370-005056b48fd2",
                },
            }
        ),
        IscsiCredentials(
            {
                "initiator": "iqn.1992-08.com.netapp:initiator3",
                "_links": {
                    "self": {
                        "href": "/api/protocols/san/iscsi/credentials/25f617cf-94d7-11e8-8370-005056b48fd2/iqn.1992-08.com.netapp:initiator3"
                    }
                },
                "authentication_type": "deny",
                "svm": {
                    "name": "svm2",
                    "_links": {
                        "self": {
                            "href": "/api/svm/svms/25f617cf-94d7-11e8-8370-005056b48fd2"
                        }
                    },
                    "uuid": "25f617cf-94d7-11e8-8370-005056b48fd2",
                },
            }
        ),
    ]

### Retrieving specific iSCSI credentials

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import IscsiCredentials

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = IscsiCredentials(
            initiator="iqn.1992-08.com.netapp:initiator2",
            **{"svm.uuid": "25f617cf-94d7-11e8-8370-005056b48fd2"}
        )
        resource.get()
        print(resource)

Try it out

    IscsiCredentials(
        {
            "initiator": "iqn.1992-08.com.netapp:initiator2",
            "_links": {
                "self": {
                    "href": "/api/protocols/san/iscsi/credentials/25f617cf-94d7-11e8-8370-005056b48fd2/iqn.1992-08.com.netapp:initiator2"
                }
            },
            "chap": {"inbound": {"user": "user1"}},
            "authentication_type": "chap",
            "svm": {
                "name": "svm2",
                "_links": {
                    "self": {"href": "/api/svm/svms/25f617cf-94d7-11e8-8370-005056b48fd2"}
                },
                "uuid": "25f617cf-94d7-11e8-8370-005056b48fd2",
            },
        }
    )

### Updating the authentication type of iSCSI credentials

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import IscsiCredentials

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = IscsiCredentials(
            initiator="iqn.1992-08.com.netapp:initiator2",
            **{"svm.uuid": "25f617cf-94d7-11e8-8370-005056b48fd2"}
        )
        resource.authentication_type = "chap"
        resource.chap = {"inbound": {"user": "user1", "password": "password1"}}
        resource.patch()

### Updating the initiator address list of iSCSI credentials

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import IscsiCredentials

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = IscsiCredentials(
            initiator="iqn.1992-08.com.netapp:initiator2",
            **{"svm.uuid": "25f617cf-94d7-11e8-8370-005056b48fd2"}
        )
        resource.initiator_address = {
            "ranges": [{"start": "192.168.0.0", "end": "192.168.255.255"}]
        }
        resource.patch()

### Deleting iSCSI credentials

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import IscsiCredentials

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = IscsiCredentials(
            initiator="iqn.1992-08.com.netapp:initiator2",
            **{"svm.uuid": "25f617cf-94d7-11e8-8370-005056b48fd2"}
        )
        resource.delete()

## Classes

`class IscsiCredentials (*args, **kwargs)`

  Allows interaction with IscsiCredentials objects on the host

  Initialize the instance of the resource.

  Any keyword arguments are set on the instance as properties. For example, if the class was named 'MyResource', then this statement would be true:

      MyResource(name='foo').name == 'foo'

  ## Args

  `*args`
    Each positional argument represents a parent key as used in the URL of the object. That is, each value will be used to fill in a segment of the URL which refers to some parent object. The order of these arguments must match the order they are specified in the URL, from left to right.
  `**kwargs`
    each entry will have its key set as an attribute name on the instance and its value will be the value of that attribute.

  ### Ancestors

  - Resource

  ### Static methods

  `def count_collection (*args, connection: HostConnection = None, **kwargs) -> int`

    Returns a count of all IscsiCredentials resources that match the provided query

    This calls GET on the object to determine the number of records. It is more efficient than calling get_collection() because it will not construct any objects. Query parameters can be passed in as kwargs to determine a count of objects that match some filtered criteria.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the count of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. These query parameters can affect the count. A return_records query param will be ignored.

    ## Returns

    On success, returns an integer count of the objects of this type. On failure, returns -1.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400, or if there is no connection available to use either passed in or on the library.

  `def delete_collection (*args, records: Iterable[ForwardRef('IscsiCredentials')] = None, body: Union[Resource, dict] = None, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, connection: HostConnection = None, **kwargs) -> NetAppResponse`

    Deletes specified iSCSI credentials.

    ### Related ONTAP commands

    - `vserver iscsi security delete`

    ### Learn more

    - `DOC /protocols/san/iscsi/credentials`

    Delete all objects in a collection which match the given query.

    All records on the host which match the query will be deleted.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to delete the collection of bars for a particular foo, the foo.name value should be passed.
    `records`
      Can be provided in place of a query. If so, this list of objects will be deleted from the host.
    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be deleted.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def fast_get_collection (*args, connection: HostConnection = None, max_records: int = None, **kwargs) -> Iterable[RawResource]`

    Returns a list of RawResources that represent IscsiCredentials resources that match the provided query

    Fetch a list of all objects of this type from the host.

        This is a lazy fetch, making API calls only as necessary when the result
        of this call is iterated over. For instance, if max_records is set to 5,
        then iterating over the collection causes an API call to be sent to the
        server once for every 5 records. If the client stops iterating before
        getting to the 6th record, then no additional API calls are made.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `max_records`
      The maximum number of records to return per call
    `raw`
      return a list of `netapp_ontap.resource.RawResource` objects that require to be promoted before any RESTful operations can be used on them. Setting this argument to True makes get_collection substantially quicker when many records are returned from the server.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A list of `Resource` objects

    ## Raises

    `NetAppRestError`: If there is no connection available to use either passed in or on the library. This would be not be raised when get_collection() is called, but rather when the result is iterated.

  `def find (*args, connection: HostConnection = None, **kwargs) -> Resource`

    Retrieves iSCSI credentials.

    ### Related ONTAP commands

    - `vserver iscsi security show`

    ### Learn more

    - `DOC /protocols/san/iscsi/credentials`

    Find an instance of an object on the host given a query.

    The host will be queried with the provided key/value pairs to find a matching resource. If 0 are found, None will be returned. If more than 1 is found, an error will be raised or returned. If there is exactly 1 matching record, then it will be returned.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to find a bar for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `Resource` object containing the details of the object or None if no matches were found.

    ## Raises

    `NetAppRestError`: If the API call returned more than 1 matching resource.

  `def get_collection (*args, connection: HostConnection = None, max_records: int = None, **kwargs) -> Iterable[Resource]`

    Retrieves iSCSI credentials.

    ### Related ONTAP commands

    - `vserver iscsi security show`

    ### Learn more

    - `DOC /protocols/san/iscsi/credentials`

    Fetch a list of all objects of this type from the host.

        This is a lazy fetch, making API calls only as necessary when the result
        of this call is iterated over. For instance, if max_records is set to 5,
        then iterating over the collection causes an API call to be sent to the
        server once for every 5 records. If the client stops iterating before
        getting to the 6th record, then no additional API calls are made.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `max_records`
      The maximum number of records to return per call
    `raw`
      return a list of `netapp_ontap.resource.RawResource` objects that require to be promoted before any RESTful operations can be used on them. Setting this argument to True makes get_collection substantially quicker when many records are returned from the server.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A list of `Resource` objects

    ## Raises

    `NetAppRestError`: If there is no connection available to use either passed in or on the library. This would be not be raised when get_collection() is called, but rather when the result is iterated.

  `def patch_collection (body: dict, *args, records: Iterable[ForwardRef('IscsiCredentials')] = None, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, connection: HostConnection = None, **kwargs) -> NetAppResponse`

    Updates specified iSCSI credentials.

    ### Related ONTAP commands

    - `vserver iscsi security add-initiator-address-ranges`
    - `vserver iscsi security default`
    - `vserver iscsi security modify`
    - `vserver iscsi security remove-initiator-address-ranges`

    ### Learn more

    - `DOC /protocols/san/iscsi/credentials`

    Patch all objects in a collection which match the given query.

    All records on the host which match the query will be patched with the provided body.

    ## Args

    `body`
      A dictionary of name/value pairs to set on all matching members of the collection. The body argument will be ignored if records is provided.
    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to patch the collection of bars for a particular foo, the foo.name value should be passed.
    `records`
      Can be provided in place of a query. If so, this list of objects will be patched on the host.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be patched.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def post_collection (records: Iterable[ForwardRef('IscsiCredentials')], *args, hydrate: bool = False, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, connection: HostConnection = None, **kwargs) -> Union[List[IscsiCredentials], NetAppResponse]`

    Creates iSCSI credentials.

    ### Required properties

    - `svm.uuid` or `svm.name` - Existing SVM in which to create the iSCSI credentials.
    - `initiator` - Initiator for which the iSCSI credentials are to be created.
    - `authentication_type` - Type of authentication to use for the credentials.

    ### Recommended optional properties

    - `chap.inbound.user` - In-bound CHAP authentication user name.
    - `chap.inbound.password` - In-bound CHAP authentication password.
    - `chap.outbound.user` - Out-bound CHAP authentication user name.
    - `chap.outbound.password` - Out-bound CHAP authentication password.

    ### Related ONTAP commands

    - `vserver iscsi security create`

    ### Learn more

    - `DOC /protocols/san/iscsi/credentials`

    Send this collection of objects to the host as a creation request.

    ## Args

    `records`
      A list of `Resource` objects to send to the server to be created.
    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to create a bar for a particular foo, the foo.name value should be passed.
    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of each object. When hydrate is set to True, poll must also be set to True.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be patched.

    ## Returns

    A list of `Resource` objects matching the provided type which have been created by the host and returned. This is not the same list that was provided, so to continue using the object, you should save this list. If poll is set to False, then a `NetAppResponse` object is returned instead.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Methods

  `def delete (self, body: Union[Resource, dict] = None, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, **kwargs) -> NetAppResponse`

    Deletes specified iSCSI credentials.

    ### Related ONTAP commands

    - `vserver iscsi security delete`

    ### Learn more

    - `DOC /protocols/san/iscsi/credentials`

    Send a deletion request to the host for this object.

    ## Args

    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def get (self, **kwargs) -> NetAppResponse`

    Retrieves specified iSCSI credentials.

    ### Related ONTAP commands

    - `vserver iscsi security show`

    ### Learn more

    - `DOC /protocols/san/iscsi/credentials`

    Fetch the details of the object from the host.

    Requires the keys to be set (if any). After returning, new or changed properties from the host will be set on the instance.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400 or if not all of the keys required are present and config.STRICT_GET has been set to True.

  `def patch (self, hydrate: bool = False, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, **kwargs) -> NetAppResponse`

    Updates specified iSCSI credentials.

    ### Related ONTAP commands

    - `vserver iscsi security add-initiator-address-ranges`
    - `vserver iscsi security default`
    - `vserver iscsi security modify`
    - `vserver iscsi security remove-initiator-address-ranges`

    ### Learn more

    - `DOC /protocols/san/iscsi/credentials`

    Send the difference in the object's state to the host as a modification request.

    Calculates the difference in the object's state since the last time we interacted with the host and sends this in the request body.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def post (self, hydrate: bool = False, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, **kwargs) -> NetAppResponse`

    Creates iSCSI credentials.

    ### Required properties

    - `svm.uuid` or `svm.name` - Existing SVM in which to create the iSCSI credentials.
    - `initiator` - Initiator for which the iSCSI credentials are to be created.
    - `authentication_type` - Type of authentication to use for the credentials.

    ### Recommended optional properties

    - `chap.inbound.user` - In-bound CHAP authentication user name.
    - `chap.inbound.password` - In-bound CHAP authentication password.
    - `chap.outbound.user` - Out-bound CHAP authentication user name.
    - `chap.outbound.password` - Out-bound CHAP authentication password.

    ### Related ONTAP commands

    - `vserver iscsi security create`

    ### Learn more

    - `DOC /protocols/san/iscsi/credentials`

    Send this object to the host as a creation request.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Inherited members

  - `Resource`:
    - `from_dict`
    - `get_collection_url`
    - `get_connection`
    - `instance_location`
    - `path_keys`
    - `poll`
    - `set_connection`
    - `to_dict`
    - `validate_schema`
`class IscsiCredentialsSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the IscsiCredentials object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `authentication_type: str GET POST PATCH`

    The iSCSI authentication type. Required in POST; optional in PATCH.

    Valid choices:

    - chap
    - none
    - deny
  `chap: IscsiCredentialsChap GET POST PATCH`

    Challenge-Handshake Authentication Protocol (CHAP) credentials.

  `initiator: str GET POST`

    The iSCSI initiator to which the credentials apply. Required in POST.

    Example: iqn.1998-01.com.corp.iscsi:name1

  `initiator_address: IscsiCredentialsInitiatorAddress GET POST PATCH`

    Initiator address ranges.

  `links: SelfLink GET`

    The links field of the iscsi_credentials.

  `svm: Svm GET POST`

    The svm field of the iscsi_credentials.